
## CATO-CLI - mutation.policy.antiMalwareFileHash.updatePolicy:
[Click here](https://api.catonetworks.com/documentation/#mutation-mutation.policy.antiMalwareFileHash.updatePolicy) for documentation on this operation.

### Usage for mutation.policy.antiMalwareFileHash.updatePolicy:

```bash
catocli mutation policy antiMalwareFileHash updatePolicy -h

catocli mutation policy antiMalwareFileHash updatePolicy <json>

catocli mutation policy antiMalwareFileHash updatePolicy --json-file mutation.policy.antiMalwareFileHash.updatePolicy.json

catocli mutation policy antiMalwareFileHash updatePolicy '{"antiMalwareFileHashPolicyMutationInput":{"policyMutationRevisionInput":{"id":"id"}},"antiMalwareFileHashPolicyUpdateInput":{"state":"ENABLED"}}'

catocli mutation policy antiMalwareFileHash updatePolicy '{
    "antiMalwareFileHashPolicyMutationInput": {
        "policyMutationRevisionInput": {
            "id": "id"
        }
    },
    "antiMalwareFileHashPolicyUpdateInput": {
        "state": "ENABLED"
    }
}'
```

#### Operation Arguments for mutation.policy.antiMalwareFileHash.updatePolicy ####

`accountId` [ID] - (required) N/A    
`antiMalwareFileHashPolicyMutationInput` [AntiMalwareFileHashPolicyMutationInput] - (required) N/A    
`antiMalwareFileHashPolicyUpdateInput` [AntiMalwareFileHashPolicyUpdateInput] - (required) N/A    
